.comment {
  color: #666;
}
.string {
  color: #489047;
}
.string .source,
.string .meta.embedded.line {
  color: #5A5A5A;
}
.string .punctuation.section.embedded {
  color: #920B2D;
}
.string .punctuation.section.embedded .source {
  color: #920B2D;
}
.constant.numeric {
  color: #D14;
}
.constant.language {
  color: #606aa1;
}
.constant.character,
.constant.other {
  color: #606aa1;
}
.constant.symbol {
  color: #990073;
}
.constant.numeric.line-number.find-in-files .match {
  color: rgba(143, 190, 0, 0.63);
}
/* For 'rw', 'copy' etc. */
.entity.name.type.trait {
  color: #555CEE;
}
.entity.name.type.class {
  color: #363F84;
}
.variable.other {
  color: #CC0050;
}
.variable {
  color: #E8756B;
}
.variable.parameter {
  color: #606aa1;
}
.keyword {
  color: #222;
  font-weight: bold;
}
.keyword.unit {
  color: #445588;
}
.keyword.special-method {
  color: #0086B3;
}
.storage {
  color: #222;
}
.storage.type {
  color: #222;
}
.entity.name.class {
  color: #606aa1;
}
.entity.other.inherited-class {
  color: #606aa1;
}
.entity.name.function {
  color: #900;
}
/* Regex/Grammars */
.string.regexp.construct {
  color: #0078FF;
}
/* `token`, `regex` */
.storage.type.declare.regexp.named {
  color: #393276;
}
/* The name of the named regex */
.entity.name.function.regexp {
  color: #7415E9;
}
.entity.name.function.regexp.named.TOP {
  color: #158de9;
}
/* /<this>/ */
.variable.other.identifier.regexname {
  color: #a52020;
}
.entity.name.tag {
  color: #008080;
}
.entity.other.attribute-name {
  color: #458;
  font-weight: bold;
}
.entity.name.filename.find-in-files {
  color: #E6DB74;
}
.support.constant,
.support.function,
.support.type {
  color: #458;
}
.support.class {
  color: #008080;
}
.invalid {
  color: #F8F8F0;
  background-color: #00A8C6;
}
.invalid.deprecated {
  color: #F8F8F0;
  background-color: #8FBE00;
}
.meta.structure.dictionary.json > .string.quoted.double.json,
.meta.structure.dictionary.json > .string.quoted.double.json .punctuation.string {
  color: #000080;
}
.meta.structure.dictionary.value.json > .string.quoted.double.json {
  color: #d14;
}
.meta.diff,
.meta.diff.header {
  color: #75715E;
}
.css.support.property-name {
  font-weight: bold;
  color: #333;
}
.css.constant {
  color: #099;
}
.source.gfm {
  color: #444;
}
.gfm .markup.heading {
  color: #111;
}
.gfm .link {
  color: #888;
}
.gfm .variable.list {
  color: #888;
}
.markdown .paragraph {
  color: #444;
}
.markdown .heading {
  color: #111;
}
.markdown .link {
  color: #888;
}
.markdown .link .string {
  color: #888;
}

.storage, .storage.declarator {
    font-weight: bold;
    color: #A626A4;
}
/* Some preexisting Atom tags, probably not needed but moving to the end */
atom-text-editor {
  background-color: white;
  color: #555;
}
atom-text-editor .invisible-character {
  color: rgba(85, 85, 85, 0.2);
}
atom-text-editor .indent-guide {
  color: rgba(85, 85, 85, 0.2);
}
atom-text-editor .wrap-guide {
  background-color: rgba(85, 85, 85, 0.2);
}
atom-text-editor .gutter {
  color: #555;
  background: white;
}
atom-text-editor .gutter .line-number.folded,
atom-text-editor .gutter .line-number:after,
atom-text-editor .fold-marker:after {
  color: #e87b00;
}
atom-text-editor .invisible {
  color: #555;
}
atom-text-editor .selection .region {
  background-color: #e1e1e1;
}
atom-text-editor .bracket-matcher .region {
  background-color: #C9C9C9;
  opacity: .7;
  border-bottom: 0 none;
}
atom-text-editor.is-focused .cursor {
  border-color: black;
}
atom-text-editor.is-focused .selection .region {
  background-color: #afc4da;
}
atom-text-editor.is-focused .line-number.cursor-line-no-selection,
atom-text-editor.is-focused .line.cursor-line {
  background-color: rgba(255, 255, 134, 0.34);
}
